﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Drawing;
using HeuristicLab.Common;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Core.Networks {
  [StorableClass]
  public sealed class NodeVisualProperties : VisualProperties, INodeVisualProperties {
    [Storable]
    private double x;
    public double X {
      get { return x; }
      set {
        if (x == value) return;
        x = value;
        OnChanged();
      }
    }

    [Storable]
    private double y;
    public double Y {
      get { return y; }
      set {
        if (y == value) return;
        y = value;
        OnChanged();
      }
    }

    [Storable]
    private double width;
    public double Width {
      get { return width; }
      set {
        if (width == value) return;
        width = value;
        OnChanged();
      }
    }

    [Storable]
    private double height;
    public double Height {
      get { return height; }
      set {
        if (height == value) return;
        height = value;
        OnChanged();
      }
    }

    [Storable]
    private Color color;
    public Color Color {
      get { return color; }
      set {
        if (color == value) return;
        color = value;
        OnChanged();
      }
    }

    #region Constructors & Cloning
    [StorableConstructor]
    private NodeVisualProperties(bool deserializing) : base(deserializing) { }
    private NodeVisualProperties(NodeVisualProperties original, Cloner cloner)
      : base(original, cloner) {
      x = original.x;
      y = original.y;
      width = original.width;
      height = original.height;
      color = original.color;
    }

    public NodeVisualProperties() {
      x = double.NaN;
      y = double.NaN;
      width = double.NaN;
      height = double.NaN;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new NodeVisualProperties(this, cloner);
    }
    #endregion
  }
}
